# RevRecTriggerCondition

Specifies the revenue recognition trigger condition.    * `Contract Effective Date`    * `Service Activation Date`   * `Customer Acceptance Date` 

## Enum

* `CONTRACT_EFFECTIVE_DATE` (value: `'Contract Effective Date'`)

* `SERVICE_ACTIVATION_DATE` (value: `'Service Activation Date'`)

* `CUSTOMER_ACCEPTANCE_DATE` (value: `'Customer Acceptance Date'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


